ordered-collections.kernel.interval


includes?clj

(includes? i0 i1)

Inclusive intervals? [==========] [====]

Inclusive intervals?    [==========]
[====]
sourceraw docstring

intersects?clj

(intersects? i0 i1)

returns true if there is any common point between intervals i0 and i1. For closed intervals where a <= b is guaranteed (via ordered-pair), this is equivalent to: a0 <= b1 AND a1 <= b0.

returns true if there is any common point between intervals i0 and i1.
For closed intervals where a <= b is guaranteed (via ordered-pair),
this is equivalent to: a0 <= b1 AND a1 <= b0.
sourceraw docstring

ordered-pairclj

(ordered-pair x)
(ordered-pair x y)

Ensure a normalized interval pair.

Ensure a normalized interval pair.
sourceraw docstring

ordered-pair?clj

(ordered-pair? x)

valid interval pair?

valid interval pair?
sourceraw docstring

overlaps?clj

(overlaps? i0 i1)

Overlapping intervals? [=========] [=========]

Overlapping intervals?   [=========]
[=========]
sourceraw docstring

PIntervalcljprotocol

an interval is represented as an ordered pair of endpoints

an interval is represented as an ordered pair of endpoints

aclj

(a _)

interval start coordinate

interval start coordinate

bclj

(b _)

interval end coordinate

interval end coordinate
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries