ordered-collections.readers

Tagged literal reader functions for EDN round-tripping.

These functions are referenced by data_readers.clj and are called by the Clojure reader when it encounters tagged literals like #ordered/set.

For use with clojure.edn/read-string, pass readers as the :readers option.

Tagged literal reader functions for EDN round-tripping.

These functions are referenced by data_readers.clj and are called by
the Clojure reader when it encounters tagged literals like #ordered/set.

For use with clojure.edn/read-string, pass `readers` as the :readers option.
raw docstring

interval-mapclj

source

interval-setclj

source

ordered-mapclj

source

ordered-multisetclj

source

ordered-setclj

source

priority-queueclj

source

range-mapclj

source

readersclj

Map of tag symbols to reader functions. Pass to clojure.edn/read-string as the :readers option:

(clojure.edn/read-string {:readers readers} s)

Map of tag symbols to reader functions.
Pass to clojure.edn/read-string as the :readers option:

  (clojure.edn/read-string {:readers readers} s)
sourceraw docstring

ropeclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries