ordered-collections.types.interop

Protocol extensions for interoperability with standard Clojure collections.

Extends ordered-collections protocols to:

  • PersistentHashSet
  • PersistentTreeSet
  • PersistentTreeMap

This allows protocol functions like union, intersection, nearest, etc. to work with standard Clojure sorted collections.

Protocol extensions for interoperability with standard Clojure collections.

Extends ordered-collections protocols to:
- PersistentHashSet
- PersistentTreeSet
- PersistentTreeMap

This allows protocol functions like union, intersection, nearest, etc.
to work with standard Clojure sorted collections.
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries