ordered-collections.types.rope

Persistent rope-like indexed sequence backed by an implicit-index weight-balanced tree.

Persistent rope-like indexed sequence backed by an implicit-index
weight-balanced tree.
raw docstring

+transient-rebuild-threshold+clj

source

ropeclj

(rope)
(rope coll)
source

rope-chunk-countclj

(rope-chunk-count v)

Number of internal chunks. O(1).

Number of internal chunks. O(1).
sourceraw docstring

rope-chunks-reverseclj

(rope-chunks-reverse v)

Reverse seq of internal chunk vectors.

Reverse seq of internal chunk vectors.
sourceraw docstring

rope-concatclj

(rope-concat x)
(rope-concat left right)
(rope-concat left right & more)

Concatenate ropes or rope-coercible collections. One argument: returns it as a rope. Two arguments: O(log n) binary tree join. Three or more: O(total chunks) bulk construction.

Concatenate ropes or rope-coercible collections.
One argument: returns it as a rope.
Two arguments: O(log n) binary tree join.
Three or more: O(total chunks) bulk construction.
sourceraw docstring

rope-concat-allclj

(rope-concat-all & xs)

Bulk concatenation of rope values or rope-coercible collections. Collects all chunks and builds the tree directly in O(total chunks), avoiding pairwise tree operations.

Bulk concatenation of rope values or rope-coercible collections.
Collects all chunks and builds the tree directly in O(total chunks),
avoiding pairwise tree operations.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries