(includes? i0 i1)Inclusive intervals? [==========] [====]
Inclusive intervals? [==========] [====]
(intersects? i0 i1)returns true if there is any common point between intervals i0 and i1. For closed intervals where a <= b is guaranteed (via ordered-pair), this is equivalent to: a0 <= b1 AND a1 <= b0.
returns true if there is any common point between intervals i0 and i1. For closed intervals where a <= b is guaranteed (via ordered-pair), this is equivalent to: a0 <= b1 AND a1 <= b0.
(ordered-pair x)(ordered-pair x y)Ensure a normalized interval pair.
Ensure a normalized interval pair.
(overlaps? i0 i1)Overlapping intervals? [=========] [=========]
Overlapping intervals? [=========] [=========]
an interval is represented as an ordered pair of endpoints
an interval is represented as an ordered pair of endpoints
(a _)interval start coordinate
interval start coordinate
(b _)interval end coordinate
interval end coordinate
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |