Tagged literal reader functions for EDN round-tripping.
These functions are referenced by data_readers.clj and are called by the Clojure reader when it encounters tagged literals like #ordered/set.
For use with clojure.edn/read-string, pass readers as the :readers option.
Tagged literal reader functions for EDN round-tripping. These functions are referenced by data_readers.clj and are called by the Clojure reader when it encounters tagged literals like #ordered/set. For use with clojure.edn/read-string, pass `readers` as the :readers option.
Map of tag symbols to reader functions. Pass to clojure.edn/read-string as the :readers option:
(clojure.edn/read-string {:readers readers} s)
Map of tag symbols to reader functions.
Pass to clojure.edn/read-string as the :readers option:
(clojure.edn/read-string {:readers readers} s)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |