Protocol extensions for interoperability with standard Clojure collections.
Extends ordered-collections protocols to:
This allows protocol functions like union, intersection, nearest, etc. to work with standard Clojure sorted collections.
Protocol extensions for interoperability with standard Clojure collections. Extends ordered-collections protocols to: - PersistentHashSet - PersistentTreeSet - PersistentTreeMap This allows protocol functions like union, intersection, nearest, etc. to work with standard Clojure sorted collections.
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |